#ifndef COURSE_H
#define COURSE_H

#include <string>
#include <vector>

///////////////////////////////////////////////////////////////////////////////
// course
///////////////////////////////////////////////////////////////////////////////

struct course
{
   std::string code;                   // course code, e.g., "BIP3004"
   std::string name;                   // course name, e.g., "Sistem Pertanian"
   int owner;                          // owner of the course (faculty code; code 0 means owned by all)
   int size;                           // no. of students in the course
   int leccr;                          // no. of lecture credits (1 cr = 1 hour)
   int labcr;                          // no. of lab credits (1 cr = 3 hours)
   int hourlimit;                      // no course hours on and after this hour limit
   std::vector<std::string> clashgrp;  // clash group (holds course codes)

   course();
   course(course const &rhs);

   course &operator=(course const &rhs);
   bool operator==(course const &rhs) const;
   bool operator<(course const &rhs) const;
};

///////////////////////////////////////////////////////////////////////////////
// course definitions
///////////////////////////////////////////////////////////////////////////////

inline course::course()
   : owner(0), size(0), leccr(1), labcr(0), hourlimit(17)
{}

inline course::course(course const &rhs)
   : owner(rhs.owner), code(rhs.code), name(rhs.name), size(rhs.size),
     clashgrp(rhs.clashgrp), leccr(rhs.leccr),  labcr(rhs.labcr), hourlimit(rhs.hourlimit)
{}

inline course &course::operator=(course const &rhs)
{
   owner = rhs.owner;
   code = rhs.code;
   name = rhs.name;
   size = rhs.size;
   clashgrp = rhs.clashgrp;
   leccr = rhs.leccr;
   labcr = rhs.labcr;
   hourlimit = rhs.hourlimit;
   return *this;
}

inline bool course::operator==(course const &rhs) const
{
   return (code == rhs.code);
}

inline bool course::operator<(course const &rhs) const
{
   return (code < rhs.code);
}

#endif
