#ifndef ROW_H
#define ROW_H

#include "room.h"
#include "course.h"

///////////////////////////////////////////////////////////////////////////////
// unit
///////////////////////////////////////////////////////////////////////////////

struct unit
{
   room place;          // room
   course subject;      // course
   bool bPermanent;     // true if unit cannot be altered, else false

   unit();
   unit(unit const &rhs);
   
   unit &operator=(unit const &rhs);
   bool operator<(unit const &rhs) const;
   bool operator==(unit const &rhs) const;
   bool operator==(course const &c) const;
};

///////////////////////////////////////////////////////////////////////////////
// row
///////////////////////////////////////////////////////////////////////////////

class row
{
public:
   std::vector<unit> units;

   row();
   row(row const &rhs);

   row &operator=(row const &rhs);

   // Clears courses from all units:
   //    bLec = true means clear all lecture credits
   //    bLab = true means clear all lab credits
   void ClearCourses(bool bLec=true, bool bLab=true);
   
   // Returns a list of group clashes from all units:
   //    bAdd = true means add the course codes into the list as well
   const std::vector<std::string> GroupClashes(bool bAdd=true) const;

   // Returns true if all units are valid (no clashes)
   //    bIgnore - set to true to fully check any course clashes; else set to
   //              false to ignore clashes between permanent courses
   bool IsValid(bool bIgnore=false) const;
};


///////////////////////////////////////////////////////////////////////////////
// unit definitions
///////////////////////////////////////////////////////////////////////////////

inline unit::unit()
   : bPermanent(false)
{}

inline unit::unit(unit const &rhs)
   : place(rhs.place), subject(rhs.subject), bPermanent(rhs.bPermanent)
{}

inline unit &unit::operator=(unit const &rhs)
{
   place = rhs.place;
   subject = rhs.subject;
   bPermanent = rhs.bPermanent;
   return *this;
}

inline bool unit::operator<(unit const &rhs) const
{
   return (place<rhs.place && subject<rhs.subject);
}

inline bool unit::operator==(unit const &rhs) const
{
   return (place==rhs.place && subject==rhs.subject);
}

inline bool unit::operator==(course const &c) const
{
   return (subject==c);
}

///////////////////////////////////////////////////////////////////////////////
// row definitions
///////////////////////////////////////////////////////////////////////////////

inline row::row()
{}

inline row::row(row const &rhs)
   : units(rhs.units)
{}

inline row &row::operator=(row const &rhs)
{
   units = rhs.units;
   return *this;
}

#endif
